/**
 * Intended for use as a tag function of a Tagged Template String.
 * When called as such the first argument will be a well formed template call site object
 * and the rest parameter will contain the substitution values.
 *
 *
 * @param template A well-formed template string call site representation.
 *
 * @param substitutions A set of substitution values.
 *
 * @example
 * let param = 'World';
 * const myLitTemp = html`<h1>Hello ${param}</h1>`;
 */
export declare const html: (template: TemplateStringsArray, ...substitutions: any[]) => string;
declare global {
    interface Array<T> {
        /**
         * Calls a defined callback function on each element of an array, and returns a unified string representation of the expected lit-temp generated results.
         *
         * NOTE: The callback ***must*** return a lit-temp generated string:
         * ```javascript
         * <ul>
         *    ${
         *        someArray.flatten(element => {
         *          return html`<li>${element}</li>`
         *        });
         *    }
         * </ul>
         * ```
         *
         * @param {(value: T, index: number, array: T[]) => any} fn - A function that accepts up to three arguments. The map method calls the callbackfn function one time for each element in the array.
         * @return {string} A concatenated string of all the lit-temp generated strings produced by the callback.
         *
         
         */
        flatten(fn: (value: T, index: number, array: T[]) => string): string;
    }
}
//# sourceMappingURL=index.d.ts.map